@@ -1,4 +1,4 @@
-/*#ifndef ATHREAD_H
+#ifndef ATHREAD_H
 #define ATHREAD_H
 
 #include <QThread>
@@ -25,4 +25,4 @@ signals:
 };
 
 #endif // ATHREAD_H
-*/
+
