@@ -50,7 +50,7 @@ ExerciseWindow::ExerciseWindow(QWidget *parent) :
     createMenu();
 
     timer = new QTimer(this);
-    QObject::connect(timer, SIGNAL(timeout()), this, SLOT(update()));
+    QObject::connect(timer, SIGNAL(timeout()), this, SLOT(updateTime()));
 
     myThread = new aThread(this);
     connect(myThread, SIGNAL(deviceOrientation(QString, QString, QString)),
@@ -135,6 +135,12 @@ void ExerciseWindow::loadExercise(QList<QString> name)
     myThread->start(QThread::NormalPriority);
 }
 
+void ExerciseWindow::changeEvent(QEvent *event)
+{
+    //qDebug() << label->text();
+    this->update();
+}
+
 void ExerciseWindow::showNewIngredient()
 {
     niw->load();
@@ -192,8 +198,9 @@ void ExerciseWindow::createActions()
     connect(skipAction,SIGNAL(triggered()), this, SLOT(skipWait()));
 }
 
-void ExerciseWindow::update()
+void ExerciseWindow::updateTime()
 {
+
     //count down wait
     strMin.setNum(min); strSec.setNum(sec); strSet.setNum(set);
     QString str = strMin + ":" + strSec + " rest left (" + strSet + "set)";
