@@ -36,6 +36,7 @@ private:
     void createMenu();
     void vibrate();
     void closeEvent(QCloseEvent *event);
+    void changeEvent(QEvent *event);
 
     QDBusInterface *interface;
     QDBusMessage pause;
@@ -80,7 +81,7 @@ private slots:
     void showSettings();
     void showNewExercise();
     void showNewProgram();
-    void update();
+    void updateTime();
     void checkAcc(QString x);
     void shaked();
     void stopVibrate();
