@@ -23,13 +23,15 @@ private:
 
     QStandardItemModel *modelName;
     QStandardItemModel *modelAmount;
+    QStandardItemModel*modelType;
 
     QMaemo5ValueButton *btnName;
     QMaemo5ValueButton *btnAmount;
+    QMaemo5ValueButton*btnType;
 
     QMaemo5ListPickSelector *selectorName;
     QMaemo5ListPickSelector *selectorAmount;
-
+    QMaemo5ListPickSelector *selectorType;
     QPushButton *btnAdd;
 
 private slots:
